==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
var WebDockingIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockingIndicatorDescriptionMetadata, _super);
    function WebDockingIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockingIndicatorDescriptionMetadata.b = function (a) {
        if (WebDockingIndicatorDescriptionMetadata.a == null) {
            WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
        }
        if (a.g(WebDockingIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockingIndicator");
        a.item("Position", "ExportedType:string:DockingIndicatorPosition");
        a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
        a.item("IsRoot", "Boolean");
    };
    WebDockingIndicatorDescriptionMetadata.d = function (a) {
        WebDockingIndicatorDescriptionMetadata.b(a);
        a.u("WebDockingIndicator", function () { return new WebDockingIndicatorDescription(); });
        a.t("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.$t = markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
}(Base));
export { WebDockingIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
var WebDockingIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockingIndicatorDescriptionMetadata, _super);
    function WebDockingIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockingIndicatorDescriptionMetadata.b = function (a) {
        if (WebDockingIndicatorDescriptionMetadata.a == null) {
            WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
        }
        if (a.j(WebDockingIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockingIndicator");
        a.item("Position", "ExportedType:string:DockingIndicatorPosition");
        a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
        a.item("IsRoot", "Boolean");
    };
    WebDockingIndicatorDescriptionMetadata.d = function (a) {
        WebDockingIndicatorDescriptionMetadata.b(a);
        a.aa("WebDockingIndicator", function () { return new WebDockingIndicatorDescription(); });
        a.z("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.$t = markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
}(Base));
export { WebDockingIndicatorDescriptionMetadata };
